Shufflecast
===========

[![PyPI package](https://img.shields.io/pypi/v/shufflecast.svg)](https://pypi.python.org/pypi/shufflecast)


Shufflecast is a simple script that, given a directory that contains video files
under its tree, will create and stream a shuffled playlist of the files to a
Chromecast.

Installation
------------

Just run:

```
pip install shufflecast
```

Usage
-----

Just run:

```
shufflecast <video directory>
```

Controlling playback
--------------------

You can't. It's meant to be like a TV channel that plays all your favorite
shows.

License
-------

Shufflecast is released under the BSD license.
